'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var numeral = require('numeral');
var lodashEs = require('lodash-es');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var numeral__default = /*#__PURE__*/_interopDefaultLegacy(numeral);

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);

    if (enumerableOnly) {
      symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
    }

    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

  if (_i == null) return;
  var _arr = [];
  var _n = true;
  var _d = false;

  var _s, _e;

  try {
    for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var emptyValue = '--';
var abbrList = [{
  unit: '亿',
  number: 10000 * 10000
}, {
  unit: '万',
  number: 10000
}];
numeral__default['default'].nullFormat(emptyValue); // 小数格式化

var decimalPlace = function decimalPlace() {
  var place = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  return '.'.padEnd((place > 10 ? 10 : place) + 1, '0');
};

var isEmpty = function isEmpty(value) {
  return !value && value !== 0;
}; // 备份

var numeralFormat = {
  /**
   * 整数
   * @param value
   * @returns
   */
  integer: function integer(value) {
    return numeral__default['default'](value).format('0,0');
  },

  /**
   * 数据整数使用千分位展示
   * place = 10，至多保留小数位数，默认最多10位小数
   */
  number: function number(value) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        _ref$place = _ref.place,
        place = _ref$place === void 0 ? 10 : _ref$place;

    if (isEmpty(value)) return emptyValue;
    var val = numeral__default['default'](value).format("0,0".concat('.['.padEnd((place > 10 ? 10 : place) + 2, '0'), "]"));
    return val === emptyValue ? String(value) : val;
  },

  /**
   * 定制小数位
   * @param value
   * @param param1
   * @returns
   */
  decimal: function decimal(value) {
    var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        _ref2$place = _ref2.place,
        place = _ref2$place === void 0 ? 2 : _ref2$place;

    return numeral__default['default'](value).format("0,0".concat(decimalPlace(place)));
  },

  /**
   * 小数->百分比展示
   * @param value
   * @param param1
   * @returns
   */
  percent: function percent(value) {
    var _ref3 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        _ref3$place = _ref3.place,
        place = _ref3$place === void 0 ? 2 : _ref3$place;

    if (isEmpty(value)) return emptyValue;
    return numeral__default['default'](value).format("0".concat(decimalPlace(place), "%"));
  },

  /**
   * 添加百分比符号
   * @param value
   * @param params
   * @returns
   */
  percentSuffix: function percentSuffix(value, params) {
    if (isEmpty(value)) return emptyValue;
    return ((params === null || params === void 0 ? void 0 : params.place) === undefined ? numeralFormat.number(value, params) : numeralFormat.decimal(value, params)) + '%';
  },

  /**
   * 字符串展示
   * @param value
   * @returns
   */
  string: function string(value) {
    return !isEmpty(value) ? value.toString() : '';
  },

  /**
   * 中文缩写
   * @param value
   * @param params
   * @returns
   */
  abbr: function abbr(value, params) {
    if (isEmpty(value)) return emptyValue;

    var _ref4 = params || {},
        _ref4$maxValue = _ref4.maxValue,
        maxValue = _ref4$maxValue === void 0 ? 0 : _ref4$maxValue,
        place = _ref4.place;

    var unit = '';
    var newValue = value;
    maxValue = maxValue || value;
    abbrList.some(function (abbr) {
      if (maxValue < abbr.number) return false;
      unit = abbr.unit;
      newValue = Number(value) / abbr.number;
      return true;
    });
    return numeralFormat[place ? 'decimal' : 'number'](newValue, {
      place: place
    }) + unit;
  }
};
/**
 * 分离类型与保留位数
 * 注：最多保留9位
 * @param format
 * @returns [类型，小数位（0-9位）]
 */

var parsePrecision = function parsePrecision() {
  var format = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var res = format.match(/\.([\d]*)([\S]*)/);

  if (res && (res[1] || res[2])) {
    var place = Number(res[1]);
    return [res[2], place < 10 ? place : 9];
  } else {
    return [format, undefined];
  }
};
/**
 * 获取format方法
 * @param format format类型，详情请参考NumeraTypeName类型
 * @returns format方法
 */

var getFormatter = function getFormatter() {
  var format = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  var _parsePrecision = parsePrecision(format),
      _parsePrecision2 = _slicedToArray(_parsePrecision, 2),
      type = _parsePrecision2[0],
      place = _parsePrecision2[1];

  if (place === undefined) {
    return numeralFormat[format] || numeralFormat['string'];
  } else {
    var fun = numeralFormat[type] || numeralFormat['string'];
    return function (value, params) {
      return fun(value, _objectSpread2({
        place: place
      }, params));
    };
  }
};
/**
 * 简单计算
 */

var simpleCount = {
  sum: function sum(total, value, key) {
    var val = value;

    if (value && key && _typeof(value) === 'object') {
      val = value[key];
    }

    return total + (isNaN(Number(val)) ? 0 : Number(val));
  },

  /**
   * 当前值在总数中的占比
   * 1. 当 total 为 0 时，返回：Infinity
   * 2. 当 total 为 非数值时，返回：NaN
   * @param val 当前值
   * @param total 总数
   * @returns 当前值在总数中的占比（小于1的小数表现形式）
   */
  ratio: function ratio(val, total) {
    return (isNaN(val) ? 0 : val) / total;
  }
};

var listSum = function listSum(valueList) {
  return lodashEs.reduce(valueList, simpleCount.sum, 0);
};
/**
 * 获取数组各元素百分比
 * 此方法可以保证所有子项百分比和为100%
 * @param valueList 数据集合
 * @param precision 精度
 */


var getPercentListWithPrecision = function getPercentListWithPrecision(valueList) {
  var precision = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;
  if (!(valueList === null || valueList === void 0 ? void 0 : valueList.length)) return [];
  var sum = listSum(valueList);
  if (sum === 0) return new Array(valueList.length).fill(0);
  var digits = Math.pow(10, precision);
  var votesPerQuota = lodashEs.map(valueList, function (val) {
    return (isNaN(val) ? 0 : val) / sum * digits * 100;
  });
  var targetSeats = digits * 100;
  var seats = lodashEs.map(votesPerQuota, function (votes) {
    // Assign automatic seats.
    return Math.floor(votes);
  });
  var currentSum = listSum(seats);
  var remainder = lodashEs.map(votesPerQuota, function (votes, idx) {
    // @ts-ignore
    return votes - seats[idx];
  }); // Has remainding votes.

  while (currentSum < targetSeats) {
    // Find next largest remainder.
    var max = Number.NEGATIVE_INFINITY;
    var maxId = -1;

    for (var i = 0, len = remainder.length; i < len; ++i) {
      if (remainder[i] > max) {
        max = remainder[i];
        maxId = i;
      }
    } // Add a vote to max remainder.


    ++seats[maxId];
    remainder[maxId] = 0;
    ++currentSum;
  }

  return seats.map(function (i) {
    return i / digits;
  });
};
/**
 * 获取数组中对应下标的百分比
 * 此方法可以保证所有子项百分比和为100%
 * @param valueList 数据集合
 * @param idx 数据下标
 * @param precision 精度
 */

var getPercentWithPrecision = function getPercentWithPrecision(valueList, idx) {
  var precision = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 2;
  if (!valueList || !valueList[idx]) return 0;
  var percentList = getPercentListWithPrecision(valueList, precision);
  return percentList[idx];
};

var valueFormat = /*#__PURE__*/Object.freeze({
  __proto__: null,
  numeralFormat: numeralFormat,
  parsePrecision: parsePrecision,
  getFormatter: getFormatter,
  simpleCount: simpleCount,
  getPercentListWithPrecision: getPercentListWithPrecision,
  getPercentWithPrecision: getPercentWithPrecision
});

// copy from react
var isUnitlessNumber = {
  animationIterationCount: true,
  aspectRatio: true,
  borderImageOutset: true,
  borderImageSlice: true,
  borderImageWidth: true,
  boxFlex: true,
  boxFlexGroup: true,
  boxOrdinalGroup: true,
  columnCount: true,
  columns: true,
  flex: true,
  flexGrow: true,
  flexPositive: true,
  flexShrink: true,
  flexNegative: true,
  flexOrder: true,
  gridArea: true,
  gridRow: true,
  gridRowEnd: true,
  gridRowSpan: true,
  gridRowStart: true,
  gridColumn: true,
  gridColumnEnd: true,
  gridColumnSpan: true,
  gridColumnStart: true,
  fontWeight: true,
  lineClamp: true,
  lineHeight: true,
  opacity: true,
  order: true,
  orphans: true,
  tabSize: true,
  widows: true,
  zIndex: true,
  zoom: true,
  // SVG-related properties
  fillOpacity: true,
  floodOpacity: true,
  stopOpacity: true,
  strokeDasharray: true,
  strokeDashoffset: true,
  strokeMiterlimit: true,
  strokeOpacity: true,
  strokeWidth: true
};
/**
 * Convert a value into the proper css writable value. The style name `name`
 * should be logical (no hyphens), as specified
 * in `CSSProperty.isUnitlessNumber`.
 *
 * @param {string} name CSS property name such as `topMargin`.
 * @param {*} value CSS property value such as `10px`.
 * @param {boolean} isCustomProperty
 * @return {string} Normalized style value with dimensions applied.
 */

function dangerousStyleValue(name, value, isCustomProperty) {
  var isEmpty = value === null || typeof value === 'boolean' || value === '';

  if (isEmpty) {
    return '';
  }

  if (!isCustomProperty && typeof value === 'number' && value !== 0 && !(isUnitlessNumber.hasOwnProperty(name) && isUnitlessNumber[name])) {
    return value + 'px'; // Presumes implicit 'px' suffix for unitless numbers
  }

  return String(value).trim();
}

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow
 */
var uppercasePattern = /([A-Z])/g;
var msPattern = /^ms-/;
/**
 * Hyphenates a camelcased CSS property name, for example:
 *
 *   > hyphenateStyleName('backgroundColor')
 *   < "background-color"
 *   > hyphenateStyleName('MozTransition')
 *   < "-moz-transition"
 *   > hyphenateStyleName('msTransition')
 *   < "-ms-transition"
 *
 * As Modernizr suggests (http://modernizr.com/docs/#prefixed), an `ms` prefix
 * is converted to `-ms-`.
 */

function hyphenateStyleName(name) {
  return name.replace(uppercasePattern, '-$1').toLowerCase().replace(msPattern, '-ms-');
}

var styleNameCache = {};

var processStyleName = function processStyleName(styleName) {
  if (styleNameCache.hasOwnProperty(styleName)) {
    return styleNameCache[styleName];
  }

  var result = hyphenateStyleName(styleName);
  styleNameCache[styleName] = result;
  return result;
};

function transformStyles(styles) {
  var newStyle = {};

  for (var styleName in styles) {
    if (!styles.hasOwnProperty(styleName)) {
      continue;
    }

    var isCustomProperty = styleName.indexOf('--') === 0;
    var styleValue = styles[styleName];

    if (styleValue !== null) {
      var name = isCustomProperty ? styleName : processStyleName(styleName);
      newStyle[name] = dangerousStyleValue(styleName, styleValue, isCustomProperty);
    }
  }

  return newStyle;
}

var index = /*#__PURE__*/Object.freeze({
  __proto__: null,
  transformStyles: transformStyles
});

exports.transformData = index;
exports.valueFormat = valueFormat;
