import { NumeraTypeName } from './interfaces';
export declare const numeralFormat: {
    /**
     * 整数
     * @param value
     * @returns
     */
    integer: (value: string | number) => string;
    /**
     * 数据整数使用千分位展示
     * place = 10，至多保留小数位数，默认最多10位小数
     */
    number: (value: string | number, { place }?: {
        place?: number | undefined;
    }) => string;
    /**
     * 定制小数位
     * @param value
     * @param param1
     * @returns
     */
    decimal: (value: string | number, { place }?: {
        place?: number | undefined;
    }) => string;
    /**
     * 小数->百分比展示
     * @param value
     * @param param1
     * @returns
     */
    percent: (value: string | number, { place }?: {
        place?: number | undefined;
    }) => string;
    /**
     * 添加百分比符号
     * @param value
     * @param params
     * @returns
     */
    percentSuffix: (value: string | number, params: any) => string;
    /**
     * 字符串展示
     * @param value
     * @returns
     */
    string: (value: string | number) => string;
    /**
     * 中文缩写
     * @param value
     * @param params
     * @returns
     */
    abbr: (value: string | number, params: any) => string;
};
/**
 * 分离类型与保留位数
 * 注：最多保留9位
 * @param format
 * @returns [类型，小数位（0-9位）]
 */
export declare const parsePrecision: (format?: string) => [NumeraTypeName, number | undefined];
/**
 * 获取format方法
 * @param format format类型，详情请参考NumeraTypeName类型
 * @returns format方法
 */
export declare const getFormatter: (format?: string) => (value: string | number, { place }?: {
    place?: number | undefined;
}) => string;
/**
 * 简单计算
 */
export declare const simpleCount: {
    sum(total: number, value: any, key?: string | undefined): number;
    /**
     * 当前值在总数中的占比
     * 1. 当 total 为 0 时，返回：Infinity
     * 2. 当 total 为 非数值时，返回：NaN
     * @param val 当前值
     * @param total 总数
     * @returns 当前值在总数中的占比（小于1的小数表现形式）
     */
    ratio(val: number, total: number): number;
};
/**
 * 获取数组各元素百分比
 * 此方法可以保证所有子项百分比和为100%
 * @param valueList 数据集合
 * @param precision 精度
 */
export declare const getPercentListWithPrecision: (valueList: number[], precision?: number) => any[];
/**
 * 获取数组中对应下标的百分比
 * 此方法可以保证所有子项百分比和为100%
 * @param valueList 数据集合
 * @param idx 数据下标
 * @param precision 精度
 */
export declare const getPercentWithPrecision: (valueList: number[], idx: number, precision?: number) => any;
